#
# spec file for package openstack-neutron-zvm-agent
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define component neutron-zvm-plugin

%define version_unconverted 11.0.0.0rc2.dev1

Name:           openstack-neutron-zvm-agent
Version:        11.0.0.0~xrc2~dev1
Release:        1.1
Summary:        Z/VM Driver for OpenStack Compute (Neutron)
License:        EPL-1.0
Group:          System/Management
Url:            https://wiki.openstack.org/wiki/ZVMDriver
Source:         http://tarballs.openstack.org/networking-zvm/networking-zvm-master.tar.gz
# systemd service files
Source10:       %{name}.service
BuildRequires:  openstack-suse-macros
BuildRequires:  python-base
BuildRequires:  python-pbr
BuildRequires:  python-setuptools
BuildRequires:  systemd-rpm-macros
%{?systemd_requires}
Requires:       python >= 2.7
#dependeny is not upstream..
Requires:       openstack-neutron
Requires:       python-oslo.config >= 3.14.0
Requires:       python-oslo.log >= 3.11.0
Requires:       python-oslo.serialization >= 1.10.0
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch

%description
The z/VM ML2 Mechanism driver and Neutron z/VM Agent for Openstack Neutron.

%package test
Summary:        Z/VM Driver for OpenStack (Neutron) - Testsuite
Group:          System/Management
Requires:       %{name} = %{version}
Requires:       python-fixtures >= 3.0.0
Requires:       python-mock >= 2.0
Requires:       python-mox >= 0.5.3
Requires:       python-nova
Requires:       python-oslotest >= 1.10.0
Requires:       python-python-subunit >= 0.0.18
Requires:       python-testrepository >= 0.0.18
Requires:       python-testscenarios >= 0.4
Requires:       python-testtools >= 1.4.0

%prep
%setup -q -n %{component}-%{version_unconverted}
%openstack_cleanup_prep

%description test
The testsuite for the z/VM driver for OpenStack Neutron.

%build
python setup.py build

%install
python setup.py install --root %{buildroot} --prefix %{_prefix}

install -d -m 755 %{buildroot}%{_bindir}/
install -d -m 755 %{buildroot}%{_sysconfdir}/neutron/neutron-zvm-agent.conf.d/

install -d -m 755 %{buildroot}%{_sysconfdir}/neutron/plugins/zvm/
install -d -m 755 %{buildroot}%{python_sitelib}/neutron/plugins/zvm/
install -d -m 755 %{buildroot}%{python_sitelib}/neutron/plugins/zvm/agent/
install -d -m 755 %{buildroot}%{python_sitelib}/neutron/plugins/zvm/common/
install -d -m 755 %{buildroot}%{python_sitelib}/neutron/plugins/drivers/
install -d -m 755 %{buildroot}%{python_sitelib}/neutron/plugins/drivers/zvm/
install -d -m 755 %{buildroot}%{python_sitelib}/neutron/plugins/ml2/drivers/zvm/
# test
install -d -m 755 %{buildroot}%{python_sitelib}/neutron/tests/
install -d -m 755 %{buildroot}%{python_sitelib}/neutron/tests/unit/
install -d -m 755 %{buildroot}%{python_sitelib}/neutron/tests/unit/plugins/
install -d -m 755 %{buildroot}%{python_sitelib}/neutron/tests/unit/plugins/ml2/
install -d -m 755 %{buildroot}%{python_sitelib}/neutron/tests/unit/plugins/zvm/

# Install systemd unit services
mkdir -p %{buildroot}%{_sbindir} %{buildroot}%{_unitdir}
install -p -D -m 444 %{SOURCE10} %{buildroot}%{_unitdir}/%{name}.service
ln -s %{_sbindir}/service %{buildroot}%{_sbindir}/rc%{name}

mv %{buildroot}%{_sysconfdir}/neutron/plugins/zvm/neutron_zvm_plugin.ini{.sample,}
cp -a neutron/plugins/zvm %{buildroot}%{python_sitelib}/neutron/plugins/
cp -a neutron/plugins/ml2/drivers/zvm %{buildroot}%{python_sitelib}/neutron/plugins/ml2/drivers
# test
cp -a neutron/tests/unit/plugins/zvm %{buildroot}%{python_sitelib}/neutron/tests/unit/plugins/
cp -a neutron/tests/unit/plugins/ml2/zvm %{buildroot}%{python_sitelib}/neutron/tests/unit/plugins/ml2

%pre
%service_add_pre %{name}.service

%post
%service_add_post %{name}.service

%preun
%stop_on_removal %{name}.service

%postun
%restart_on_update %{name}.service
%service_del_postun %{name}.service

%files
%defattr(-,root,root,-)
%dir %{_sysconfdir}/neutron
%dir %{_sysconfdir}/neutron/neutron-zvm-agent.conf.d/
%dir %{_sysconfdir}/neutron/plugins
%dir %{_sysconfdir}/neutron/plugins/zvm
%config(noreplace) %{_sysconfdir}/neutron/plugins/zvm/neutron_zvm_plugin.ini
%{_unitdir}/%{name}.service
%{_bindir}/neutron-zvm-agent
%{_sbindir}/rc%{name}
%dir %{python_sitelib}/neutron
%dir %{python_sitelib}/neutron/plugins
%dir %{python_sitelib}/neutron/plugins/ml2
%dir %{python_sitelib}/neutron/plugins/ml2/drivers
%{python_sitelib}/neutron/plugins/ml2/drivers/zvm
%{python_sitelib}/neutron/plugins/zvm
%{python_sitelib}/neutron_zvm*.egg-info
# Part of test subpackage
%exclude %{python_sitelib}/neutron/tests/unit/plugins

%files test
%defattr(-,root,root)
%dir %{python_sitelib}/neutron/tests
%dir %{python_sitelib}/neutron/tests/unit
%dir %{python_sitelib}/neutron/tests/unit/plugins
%dir %{python_sitelib}/neutron/tests/unit/plugins/ml2
%dir %{python_sitelib}/neutron/tests/unit/plugins/zvm

%changelog
* Thu Jun 21 2018 cloud-devel@suse.de
- Update to version neutron-zvm-plugin-11.0.0.0rc2.dev1:
  * update setup.cfg to install all zvm plugin modules
  11.0.0.rc1
* Fri May 18 2018 cloud-devel@suse.de
- Update to version neutron-zvm-plugin-10.0.1.dev3:
  * Set device up event after the nic is coupled to vswitch
* Thu Apr 19 2018 cloud-devel@suse.de
- Update to version neutron-zvm-plugin-10.0.1.dev2:
  * use plugin common utils from neutron-lib
* Mon Mar 19 2018 cloud-devel@suse.de
- Update to version neutron-zvm-plugin-10.0.1.dev1:
  * The neutron.common.topics module was rehomed into neutron-lib
  10.0.0
* Fri Jan 19 2018 cloud-devel@suse.de
- Update to version neutron-zvm-plugin-8.0.1.dev16:
  * Modify conf and fix bug about token\_path
* Tue Jan 16 2018 cloud-devel@suse.de
- Update to version neutron-zvm-plugin-8.0.1.dev15:
  * SSL support and requirement
* Sat Jan  6 2018 cloud-devel@suse.de
- Update to version neutron-zvm-plugin-8.0.1.dev14:
  * zvmconnector is a library that invoke zvmsdk API to enable cloud management
* Tue Oct 24 2017 cloud-devel@suse.de
- Update to version neutron-zvm-plugin-8.0.1.dev13:
  * use plugin constants from neutron-lib
* Wed Aug 23 2017 cloud-devel@suse.de
- Update to version neutron-zvm-plugin-8.0.1.dev12:
  * switch to zvm sdk
* Thu Aug 10 2017 cloud-devel@suse.de
- Update to version neutron-zvm-plugin-8.0.1.dev11:
  * Removes unnecessary utf-8 encoding
  * Add advanced network settings
* Thu May  4 2017 cloud-devel@suse.de
- Update to version neutron-zvm-plugin-8.0.1.dev9:
  * Add single vlan doc
  * Add singleflat for neutron agent doc
  * Adjust the doc looks
  * change README file content
* Wed May  3 2017 cloud-devel@suse.de
- Update to version neutron-zvm-plugin-8.0.1.dev5:
  * Remove \_LW \_LI \_LE
* Tue Apr 25 2017 cloud-devel@suse.de
- Update to version neutron-zvm-plugin-8.0.1.dev4:
  * Add handle 503 error from REST layer
  * Neutron moved context from neutron to neutron\_lib
  * fix zvm\_xcat\_ca\_file type
  * Add add\_nics\_to\_user\_direct function
  * Fix the issue of the error for '\_port\_map'
  * Change zvm\_xcat\_username,zvm\_xcat\_password default
  * Change the copyright of mech\_zvm.py
  * Upgrade log when get\_device\_fail
  * remove VIF\_TYPES in mech\_zvm.py
  * Sync the content in neutron\_zvm\_plugin.ini.sample
  * move VIF\_TYPE\_ZVM,AGENT\_TYPE\_ZVM to zvm/mech\_zvm.py
* Fri Mar 17 2017 cloud-devel@suse.de
- Update to version neutron-zvm-plugin-8.0.1.dev3:
  * Adopt community changes
* Thu Mar  9 2017 cloud-devel@suse.de
- Update to version neutron-zvm-plugin-8.0.1.dev2:
  * Neutron moved context from neutron to neutron_lib
  8.0.0
* Thu Feb 23 2017 cloud-devel@suse.de
- Update to version neutron-zvm-plugin-6.0.0.dev57:
  * Remove unused logging import
* Wed Jan 25 2017 cloud-devel@suse.de
- Update to version neutron-zvm-plugin-6.0.0.dev56:
  * Use neutron-lib portbindings api-def
* Thu Dec 22 2016 tbechtold@suse.com
- Install conf.d dir
* Tue Dec 13 2016 tbechtold@suse.com
- Fix typo in service file
* Wed Dec  7 2016 aplanas@suse.com
- systemd: remove Wants from services.
* Wed Dec  7 2016 aplanas@suse.com
- Switch to systemd service files
* Wed Dec  7 2016 cloud-devel@suse.de
- Update to version neutron-zvm-plugin-6.0.0.dev55:
  * Bump xcat minimum version to latest 2.8.3.16
* Wed Nov 16 2016 cloud-devel@suse.de
- Update to version neutron-zvm-plugin-6.0.0.dev54:
  * Fix option description
* Tue Nov 15 2016 cloud-devel@suse.de
- Update to version neutron-zvm-plugin-6.0.0.dev53:
  * fix zvm_xcat_ca_file type
* Sat Nov 12 2016 cloud-devel@suse.de
- Update to version neutron-zvm-plugin-6.0.0.dev52:
  * Use neutron lib instead neutron common code
* Wed Sep 21 2016 cloud-devel@suse.de
- Update to version neutron-zvm-plugin-6.0.0.dev51:
  * Add version check for neutron agent start
  * Performance enhance to remove couple operation
* Fri Aug 26 2016 aplanas@suse.com
- Revert generate PID file for systemd (bsc#991985)
* Tue Aug 23 2016 aplanas@suse.com
- Generate PID file for systemd (bsc#991985)
* Tue Aug 23 2016 cloud-devel@suse.de
- Update to version neutron-zvm-plugin-6.0.0.dev48:
  * Fix a bug related to a function name
  * Add add_nics_to_user_direct function
* Wed Aug 17 2016 cloud-devel@suse.de
- Update to version neutron-zvm-plugin-6.0.0.dev46:
  * Change zvm_xcat_username,zvm_xcat_password default
* Thu Aug 11 2016 cloud-devel@suse.de
- Update to version neutron-zvm-plugin-6.0.0.dev44:
  * Enable DeprecationWarning in test environments
* Tue Aug  9 2016 cloud-devel@suse.de
- Update to version neutron-zvm-plugin-6.0.0.dev43:
  * Fix the issue of the error for '_port_map'
  * Deal with unexpected response when finding exist nics
* Wed Aug  3 2016 cloud-devel@suse.de
- Update to version neutron-zvm-plugin-6.0.0.dev40:
  * Use https with CA conf
* Tue Jun 28 2016 cloud-devel@suse.de
- Update to version neutron-zvm-plugin-6.0.0.dev39:
  * Add version functions
  * Before uncouple NIC to vswitch, check whether it has vswitch info first
* Mon May 30 2016 cloud-devel@suse.de
- Update to version neutron-zvm-plugin-6.0.0.dev36:
  * Add bandit test to tox
* Tue May 24 2016 cloud-devel@suse.de
- Update to version neutron-zvm-plugin-6.0.0.dev34:
  * Make neutron-zvm-agent exception enhance
* Fri May 20 2016 cloud-devel@suse.de
- Update to version neutron-zvm-plugin-6.0.0.dev32:
  * Handle NIC 800 is created but not couple on xcat
* Tue May 17 2016 cloud-devel@suse.de
- Update to version neutron-zvm-plugin-6.0.0.dev31:
  * Add debug log into xcat request/response
* Mon May  9 2016 cloud-devel@suse.de
- Update to version neutron-zvm-plugin-6.0.0.dev30:
  * Switch to using hacking checks from neutron-lib
* Tue Apr 19 2016 cloud-devel@suse.de
- Update to version neutron-zvm-plugin-6.0.0.dev29:
  * enhance log for neutron agent
  * Fix bandit issue
* Fri Apr 15 2016 cloud-devel@suse.de
- Update to version neutron-zvm-plugin-6.0.0.dev26:
  * fix pep8 issue recently introduced by neutron
* Wed Apr 13 2016 dmueller@suse.com
- add missing dependency on openstack-neutron
* Thu Mar 10 2016 cloud-devel@suse.de
- Update to version neutron-zvm-plugin-6.0.0.dev25:
  * Make enhancement for zvm-agent log for tracking issue more easily
* Sat Feb 20 2016 dmueller@suse.com
- Update to version neutron-zvm-plugin-6.0.0.dev24:
  * Fix the errors in adding management NIC for liberty system
  * Fix setup.cfg packages entry
  * Update from global requirements
  * zvm agent fail to start because the table change in xcat
  * Change the copyright of mech_zvm.py
  * update package info for master branch
  * Remove trailing whitespace
  * Remove patching of neutron in tox environment
  * add translation hints
* Tue Dec  8 2015 dmueller@suse.com
- Update to version neutron-zvm-plugin-2015.1.0.dev14:
  * Upgrade log when get_device_fail
  * Fix pep8 error in gate
  * Update .gitreview for new namespace
  * Introduce XCAT version concept
  * remove VIF_TYPES in mech_zvm.py
  * Change smapi command to cp command in zvm-agent
  * Fix bug unsupport vswitch name started with number
  * Sync the content in neutron_zvm_plugin.ini.sample
  * move VIF_TYPE_ZVM,AGENT_TYPE_ZVM to zvm/mech_zvm.py
  * fix tox env issues
* Thu Jul 16 2015 dmueller@suse.com
- fix dependencies
* Wed Jul 15 2015 dmueller@suse.com
- clean up packaging / init script
* Wed Jul  8 2015 dmueller@suse.com
- fix requires
* Mon Jun 22 2015 mmeister@suse.com
- Initial version
